#ifndef INCLUDED_TYPES_H_
#define INCLUDED_TYPES_H_

#include <cstddef>
#include <tuple>
using Triplet = std::tuple<size_t, size_t, size_t>;

#endif
